# Generated by roxygen2: do not edit by hand

S3method(as.data.frame,grd_classes)
S3method(as.data.frame,grd_markov)
S3method(as.data.frame,grd_rank_mobility)
S3method(as.data.frame,grd_spatial_markov)
S3method(class_intervals,grd_classes)
S3method(class_intervals,grd_markov)
S3method(class_intervals,grd_spatial_markov)
S3method(lag_intervals,grd_spatial_markov)
S3method(print,grd_classes)
S3method(print,grd_markov)
S3method(print,grd_rank_mobility)
S3method(print,grd_spatial_markov)
S3method(steady_state,grd_markov)
S3method(steady_state,matrix)
S3method(transition_matrix,grd_markov)
S3method(transition_matrix,grd_spatial_markov)
export(class_intervals)
export(classify_dynamics)
export(lag_intervals)
export(markov_dynamics)
export(plot_rank_mobility)
export(plot_spatial_markov)
export(plot_transition_matrix)
export(rank_mobility)
export(spatial_markov)
export(steady_state)
export(transition_matrix)
importFrom(rlang,.data)
