#' griddy: Geospatial Distribution Dynamics
#'
#' Tidy helpers for exploratory geospatial distribution dynamics.
#'
#' @keywords internal
"_PACKAGE"

## usethis namespace: start
#' @importFrom rlang .data
## usethis namespace: end
NULL
