% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/markov.R
\name{class_intervals}
\alias{class_intervals}
\title{Class Intervals Used By A griddy Object}
\usage{
class_intervals(x, ...)
}
\arguments{
\item{x}{A griddy result object.}

\item{...}{Reserved for future methods.}
}
\value{
A tibble of class intervals when available.
}
\description{
Class Intervals Used By A griddy Object
}
\examples{
\dontshow{if (identical(Sys.getenv("IN_PKGDOWN"), "true")) (if (getRversion() >= "3.4") withAutoprint else force)(\{ # examplesIf}
panel <- data.frame(id = rep(1:3, each = 2), year = rep(2020:2021, 3), value = 1:6)
classes <- classify_dynamics(panel, id, year, value, k = 3)
class_intervals(classes)
\dontshow{\}) # examplesIf}
}
